@@ -68,7 +68,6 @@ static struct poptOption options[] = {
 /**********************************************************************/
 /* Function Prototypes                                                */
 /**********************************************************************/
-static gchar *nstr(gint);
 static gint   save_state(GnomeClient*, gint, GnomeRestartStyle, gint, GnomeInteractStyle, gint, gpointer);
 static void   session_die(gpointer);
 /**********************************************************************/
@@ -78,25 +77,6 @@ static void   session_die(gpointer);
 /* Function Definitions                                               */
 /**********************************************************************/
 
-/**
- * nstr
- * @n: number
- *
- * Description:
- * creates a new string containing a number
- *
- * Returns:
- * a new string containing a number
- **/
-static gchar *nstr(
-gint n
-){
-  gchar buf[20];
-  sprintf(buf, "%d", n);
-  return strdup(buf);
-}
-
-
 /**
  * save_state
  * @client: gnome client
@@ -123,25 +103,24 @@ gint                fast,
 gpointer            client_data
 ){
   char *argv[20];
-  gint i;
-  gint xpos, ypos;
+  int i;
+  int xpos, ypos;
 
   gdk_window_get_origin(app->window, &xpos, &ypos);
 
   i = 0;
   argv[i++] = (char *)client_data;
   argv[i++] = "-x";
-  argv[i++] = nstr(xpos);
+  argv[i++] = g_strdup_printf("%d",xpos);
   argv[i++] = "-y";
-  argv[i++] = nstr(ypos);
+  argv[i++] = g_strdup_printf("%d",ypos);
 
   gnome_client_set_restart_command(client, i, argv);
   /* i.e. clone_command = restart_command - '--sm-client-id' */
   gnome_client_set_clone_command(client, 0, NULL);
 
-  /* free memory from nstr(s) */
-  free(argv[2]);
-  free(argv[4]);
+  g_free(argv[2]);
+  g_free(argv[4]);
 
   return TRUE;
 }
@@ -194,7 +173,12 @@ char *argv[]
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain(GETTEXT_PACKAGE);
 
-  gnome_init_with_popt_table(GAME_NAME, VERSION, argc, argv, options, 0, NULL);
+  gnome_program_init (GAME_NAME, VERSION,
+ 		      LIBGNOMEUI_MODULE,
+ 		      argc, argv,
+ 		      GNOME_PARAM_POPT_TABLE, options,
+ 		      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gnobots2.png");
 
   client = gnome_master_client();
@@ -202,15 +186,15 @@ char *argv[]
   gtk_object_ref(GTK_OBJECT(client));
   gtk_object_sink(GTK_OBJECT(client));
 
-  gtk_signal_connect(GTK_OBJECT(client), "save_yourself",
+  g_signal_connect(GTK_OBJECT(client), "save_yourself",
 		     GTK_SIGNAL_FUNC(save_state), argv[0]);
-  gtk_signal_connect(GTK_OBJECT(client), "die",
+  g_signal_connect(GTK_OBJECT(client), "die",
 		     GTK_SIGNAL_FUNC(session_die), argv[0]);
 
-  app = gnome_app_new(GAME_NAME, _("Gnome Robots II") );
+  app = gnome_app_new(GAME_NAME, _("GNOME Robots II") );
   gtk_window_set_policy(GTK_WINDOW(app), FALSE, FALSE, TRUE);
 
-  gtk_signal_connect(GTK_OBJECT(app), "delete_event",
+  g_signal_connect(GTK_OBJECT(app), "delete_event",
 		     GTK_SIGNAL_FUNC(exit_cb), NULL);
 
   stbar = gnobots_statusbar_new();
@@ -218,11 +202,9 @@ char *argv[]
 
   create_game_menus();
 
-  gtk_widget_push_visual (gdk_rgb_get_visual ());
-  gtk_widget_push_colormap (gdk_rgb_get_cmap ());
+  gtk_widget_push_colormap (gdk_rgb_get_colormap ());
   game_area = gtk_drawing_area_new();
   gtk_widget_pop_colormap ();
-  gtk_widget_pop_visual ();
   gnome_app_set_contents(GNOME_APP(app), game_area);
   gtk_widget_realize(game_area);
   gtk_drawing_area_size(GTK_DRAWING_AREA(game_area), 
@@ -262,6 +244,8 @@ char *argv[]
     }
   }
 
+  update_score_state ();
+
   gtk_main();
 
   cleanup_game();
