@@ -9,6 +9,7 @@
 #include "gbdefs.h"
 #include "keyboard.h"
 #include "game.h"
+#include "menu.h"
 
 
 /**********************************************************************/
@@ -247,6 +248,7 @@ static void apply_changes(
   set_game_config(properties.selected_config);
 
   keyboard_set(properties.keys);
+  update_score_state ();
 }
 
 
@@ -840,7 +842,7 @@ void show_properties_dialog(
   /* Copy current setting into temporary */
   copy_properties(&properties, &temp_prop);
 
-  propbox = gtk_dialog_new_with_buttons (_("GnobotsII Preferences"),
+  propbox = gtk_dialog_new_with_buttons (_("GNOME Robots Preferences"),
                                          GTK_WINDOW (app),
                                          GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                          /* GTK_STOCK_HELP, GTK_RESPONSE_HELP, */
@@ -1290,6 +1292,7 @@ gboolean load_properties(
   set_game_graphics(properties.selected_graphics);
   set_game_config(properties.selected_config);
   keyboard_set(properties.keys);
+  update_score_state ();
 }
 
 
