@@ -91,7 +91,7 @@ static gboolean       player_push       = FALSE;
 /* This message will be printed in the statusline, if no message was
    specified in a game file.  */
 
-static char *default_message= N_("Gnome-Stones (c) 1998 Carsten Schaar");
+static char *default_message= N_("GNOME-Stones (c) 1998 Carsten Schaar");
 
 
 /****************************************************************************/
@@ -122,6 +122,9 @@ static void
 game_start_cb (GtkWidget *widget, gpointer data);
 
 
+static void
+show_scores_dialog (gint pos);
+
 
 /****************************************************************************/
 /* Image stuff  */
@@ -152,7 +155,7 @@ load_image_from_path (const char *relative_name)
       char       buffer[1024];
       g_snprintf (buffer, sizeof(buffer), 
 		  _("An error occured while loading the image file \"%s\".\n"
-		    "Please make sure, that Gnome-Stones is "
+		    "Please make sure, that GNOME-Stones is "
 		    "correctly installed!"), relative_name);
 					    
       widget= gtk_message_dialog_new (GTK_WINDOW(app), 
@@ -650,9 +653,8 @@ countdown_timeout_function (gpointer data)
 
 	update_score_state ();
 
-	  gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, pos);
 	  gnome_app_flash (GNOME_APP (app), _("Congratulations, you win!"));
-
+          show_scores_dialog (pos);
 
 	}
       else
@@ -841,8 +843,8 @@ iteration_timeout_function (gpointer data)
 	      /* FIXME: somewhere is a bug, that makes this needed.  */
 	      if (pos > 10) pos= 0;
 	      
-	      gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, pos);
 	      gnome_app_flash (GNOME_APP (app), _("Game over!"));
+              show_scores_dialog (pos);
 	      curtain_start (NULL);
 	    }
 	}
@@ -946,6 +948,18 @@ load_game (const gchar *filename, guint _start_cave)
 }
 
 
+static void
+show_scores_dialog (gint pos)
+{
+  GtkWidget *dialog;
+
+  dialog = gnome_scores_display ("GNOME-Stones", APP_NAME, NULL, pos);
+  if (dialog != NULL) {
+    gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(app));
+    gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+  }
+}
+
 
 /*****************************************************************************/
 /* Menu callback functions */
@@ -1017,14 +1031,14 @@ quit_cb (GtkWidget *widget, gpointer data)
 static void
 show_scores_cb (GtkWidget *widget, gpointer data)
 {
-  gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, GPOINTER_TO_INT (data));
+  show_scores_dialog (GPOINTER_TO_INT (data));
 }
 
 
 static void
 about_cb (GtkWidget *widget, gpointer data)
 {
-  GtkWidget *about= NULL;
+  static GtkWidget *about= NULL;
   GdkPixbuf *pixbuf = NULL;
   
   const gchar *authors[]= {
@@ -1037,6 +1051,10 @@ about_cb (GtkWidget *widget, gpointer data)
   /* Translator credits */
   gchar *translator_credits = _("translator_credits");
 
+  if (about != NULL) {
+    gtk_window_present (GTK_WINDOW(about));
+    return;
+  }
   {
 	  char *filename = NULL;
 
@@ -1049,14 +1067,19 @@ about_cb (GtkWidget *widget, gpointer data)
 		  g_free (filename);
 	  }
   }
-  about= gnome_about_new (_("Gnome-Stones"), VERSION,
+  about= gnome_about_new (_("GNOME-STONES"), VERSION,
 			  "(C) 1998 Carsten Schaar",
 			  _("A game."),
 			  (const char **)authors,
                           (const char **)documenters,
                           strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			  pixbuf);
+  
+  if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+  
   gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (app));
+  g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
   gtk_widget_show (about);
 }
 
@@ -1261,7 +1284,7 @@ main (int argc, char *argv[])
 		      GNOME_PARAM_APP_LIBDIR, LIBDIR, NULL);
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-stones.png");
   /* That's what a gnome application needs:  */
-  app= gnome_app_new ("gnome-stones", _("Gnome-Stones"));
+  app= gnome_app_new ("gnome-stones", _("GNOME-Stones"));
   gtk_window_set_policy  (GTK_WINDOW (app), FALSE, FALSE, TRUE);
 
   /* ... a menu line, ... */
