@@ -252,7 +252,7 @@ gboolean quit_game_cb(GtkWidget *widget, gpointer data)
 				GTK_DIALOG_MODAL,
 				GTK_MESSAGE_QUESTION,
 				GTK_BUTTONS_NONE,
-				_("Really quit GNOME Iagno?"), NULL);
+				_("Are you sure you want to quit Iagno?"), NULL);
 
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
@@ -435,7 +435,9 @@ void about_cb(GtkWidget *widget, gpointer data)
 				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				pixbuf);
 			
-			
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+				
 	g_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
 	gtk_window_set_transient_for (GTK_WINDOW(about), GTK_WINDOW(window));
@@ -457,8 +459,16 @@ gint expose_event(GtkWidget *widget, GdkEventExpose *event)
 
 gint configure_event(GtkWidget *widget, GdkEventConfigure *event)
 {
+	static int old_width = 0, old_height = 0;
 	guint i, j;
 
+	if (old_width == event->width && old_height == event->height) {
+		return TRUE;
+	} else {
+		old_width = event->width;
+		old_height = event->height;
+	}
+	
 	if (gridGC[0] != 0) {
 		gdk_draw_rectangle(buffer_pixmap,gridGC[0],1,0,0,BOARDWIDTH,BOARDHEIGHT);
 		for(i = 0; i < 8; i++)
