@@ -1111,11 +1111,6 @@ you_won (void)
 static void
 pref_dialog_response (GtkDialog *dialog, gint response, gpointer data)
 {
-	if (response == GTK_RESPONSE_HELP) {
-		gnome_help_display("prefs.html", NULL, NULL);
-		return;
-	}
-
 	gtk_widget_destroy (pref_dialog);
 	pref_dialog = NULL;
 	warn_cb = NULL;
@@ -1137,7 +1132,6 @@ properties_callback (GtkWidget *widget, gpointer data)
 	pref_dialog = gtk_dialog_new_with_buttons (_("Mahjongg - Preferences"),
 			GTK_WINDOW (window),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			NULL);
 
@@ -1388,6 +1382,10 @@ about_callback (GtkWidget *widget, gpointer data)
 				 (const gchar **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				pixbuf);
+	
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+	
 	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
 	gtk_widget_show (about);
 }
@@ -1463,7 +1461,7 @@ confirm_action (GtkWidget *widget, gpointer data)
 		
 		switch ((game_state)data) {
 		case RESTART_GAME :
-			confirm_text = _("Really restart this game?");
+			confirm_text = _("Are you sure you want to restart this game?");
 			break;
 		case QUIT_GAME :
 			/* GNOME IS AN ACRONYM, DAMNIT! */
@@ -1471,7 +1469,7 @@ confirm_action (GtkWidget *widget, gpointer data)
 			break;
 		case NEW_GAME:
 		case NEW_GAME_WITH_SEED:
-			confirm_text = _("Really start a new game?");
+			confirm_text = _("Are you sure you want to start a new game?");
 			break;
 		default:
 			confirm_text = _("Serious internal error");
@@ -2037,7 +2035,6 @@ gconf_sanity_check(void)
     gtk_dialog_run(GTK_DIALOG(dialog));
     exit(1);
   } else {
-    g_message(tileset);
     g_free (tileset);
   }
 }
@@ -2142,6 +2139,7 @@ main (int argc, char *argv [])
 
 	init_config();
 
+	score_current_mapset = strdup (mapset);
 	update_score_state ();
 
   	gnome_app_flash (GNOME_APP (window), 
